# GPF Overview

GPF(Grid-based Parsing Framework) uses the Grid structure to analyze language units and relationships, describes and calculates their attributes through Key-Value Pairs, and uses Table to represent different types of knowledge; with the help of FSA, identifies language unit combinations that satisfy specific rules; it defines a standard interface for data exchange, which can use the results of deep learning methods to perform fusion calculations in the Grid.

# Docs

For documentation on GPF and demos, please visit (http://gpf.blcu.edu.cn).

# Installing via pip

> pip install gpf
